<?php

require_once HOLO6_PLUGIN_DIR . "plugin_pages/libs/utils.php";
require_once HOLO6_PLUGIN_DIR . "plugin_pages/libs/holo6_private_settings.php";

class Holo6APIResponse {
    public $json_data;
    public $response_code;

    public function __construct($response_code, $json_data=array()) {
        $this->response_code = $response_code;
        $this->json_data = $json_data;
    }

    public function validation_json(/*string*/ $cle, $check_type=null) { // -> bool
        if (is_int($this->response_code) && (intval($this->response_code / 100) === 2)) {
             if (array_key_exists($cle, $this->json_data)) {
                if ($check_type === null) {
                    return true;
                }
                else {  // On contrôle également le type...
                    if (array_key_exists("object", $this->json_data)) {
                        return $this->json_data["object"] === $check_type;
                    }
                }
             }
        }
        return false;
    }

    public function get(/*string*/ $cle) { // -> array|int|string
        return $this->json_data[$cle];
    }

    public function toString() { // -> string
        if (is_array($this->json_data)) {
            return  "(" . $this->response_code . ") => \"" . implode(", ", $this->json_data) . "\"";
        }
        else {
            return  "(" . $this->response_code . ") => \"" . strval($this->json_data) . "\"";
        }
    }
};

class Holo6PHPClient {
    private $full_api_key = null;
    private $ignore_ssl_key_verify = false;
    private $current_collection_name = null;
    private $settings = null;

    public function __construct() {
        $current_network_id = holo6_current_site_id();
        $this->settings = new Holo6PrivateSettings($current_network_id);
        $this->full_api_key = $this->settings->getFullAPIKey();
        
        $this->current_collection_name = get_network_option($current_network_id, "holo6_database-current_collection_name", "global");
        // $this->ignore_ssl_key_verify = strcmp($this->settings->getServerName(), "hostname");  // Pour tests sur l'instance locale.
    }

    public function validateUserAPIKey() { // -> bool
        $liste_agents = $this->GetAgentsList(true);
        return $liste_agents->validation_json("agents", "list");
    }

    public function validateAdminAPIKey() { // -> bool
        return $this->validateUserAPIKey();
    }

    public function valideDatabasePassword($require_admin=true) { // -> bool
        if ($this->validateUserAPIKey() === true) {
            if (strlen($this->GetSearchDBPassword()) > 0) {
                $password = $this->GetSearchDBPassword();
                $check_account_response = $this->_post("embd/db/check_account", array("database" => "private", "password" => $password, "require_admin" => $require_admin));
                if ($check_account_response->validation_json("data", "int") === true) {
                    return $check_account_response->get("data") > 0;
                }
            }
        }
        return false;
    }

    public function GetCurrentCollectionName() { // -> string
        return $this->current_collection_name;
    }

    public function GetAPIKey() { // -> string
        return $this->settings->getAPIKey();
    }

    public function GetSearchDBPassword() { // -> string
        return $this->settings->getSearchDBPassword();
    }

    public function GetAgentsList($real_request_bool) { // -> Holo6APIResponse
        if ($real_request_bool) {
            return $this->_get("meta/v1/agents");
        }
        else { // Simule la réponse pour n'avoir que les agents "alt" et "global".
            return new Holo6APIResponse(200,
                array("object" => "list",
                    "agents" => array(
                        array(
                            "name" => "main/chat-global",
                            "description" => "Discussion simple en exploitant la base de donnée alternative",
                            "language" => "fr",
                            "type" => "agent",
                            "permissions" => array(
                                "requires_secret_key" => false
                            )

                        ),
                        array(
                            "name" => "main/chat-alt",
                            "description" => "Discussion simple en exploitant la base de donnée alternative",
                            "language" => "fr",
                            "type" => "agent",
                            "permissions" => array(
                                "requires_secret_key" => true
                            )
                        )
                    )
                )
            );
        }
    }

    public function GetAgentVar($agent_id_str, $var_name_str) {  // -> array|null
        $reponse = $this->_post("meta/getvar",
            array(
                "model" => $agent_id_str,
                "var_name" => $var_name_str
            )
        );
        if ($reponse->validation_json("var_value", "getvar_response")) {
            return $reponse->get("var_value");
        }
        return null;
    }

    public function SetAgentVar($agent_id_str, $var_name_str, $var_value /* string|int|float */) { // -> bool
        $reponse = $this->_post("meta/setvar",
            array(
                "model" => $agent_id_str,
                "var_name" => $var_name_str,
                "var_value" => $var_value
            )
        );
        if ($reponse->validation_json("result", "setvar_response")) {
            return $reponse->get("result");
        }
        return false;
    }

    public function DBGetCollectionsList($filter="*") { // -> Holo6APIResponse
        return $this->_post("embd/db/collections", array("database" => "private", "filter" => $filter));
    }

    public function DBGetDatabasesList() { // -> Holo6APIResponse
        return $this->_get("embd/db/databases");
    }

    public function DBCreatePrivateDataBase(/*string*/ $password) {
        // $this->settings->setSearchDBPassword($password); // On assigne simplement le mot de passe, la base de donnée sera crée si besoin quand on ajoutera des collections.
    }

    public function DBGetCollectionIdfromName(/*string*/ $collection_name) { // -> string
        $collections_list_request = $this->DBGetCollectionsList($collection_name);
        if ($collections_list_request->validation_json("data", "list") === true) {
            $collections_list = $collections_list_request->get("data");
            if (count($collections_list) === 1) {
                return $collections_list[0]["collection_id"];
            }
        }
        return "";
    }

    public function DBDeleteCollection(/*string*/ $collections_id) { // -> Holo6APIResponse
        $password = $this->GetSearchDBPassword();
        if (strlen($password) > 0 && strlen($collections_id) > 0) {
            return $this->_post("embd/db/reset",
                array(
                    "database" => "private",
                    "password" => $password,
                    "collections_id" => $collections_id,
                    "erase" => true,
                )
            );
        }
        return new Holo6APIResponse(513);
    }

    public function DBDeleteSourceFromCurrentCollection(/* string */ $source_name) { // -> Holo6APIResponse
        $collection_name = $this->GetCurrentCollectionName();
        $password = $this->GetSearchDBPassword();
        if (strlen($password) > 0) {
            $collection_id = $this->DBGetCollectionIdfromName($collection_name);
            if (strlen($collection_id) > 0) {
                return $this->_post("embd/db/delete",
                    array(
                        "database" => "private",
                        "password" => $password,
                        "collections_id" => $collection_id,
                        "source" => $source_name
                    )
                );
            }
        }
        return new Holo6APIResponse(513);
    }

    public function DBGetCollectionDetail(/*string*/ $collection_id, /*string*/ $source_name=null) { // -> Holo6APIResponse
        return $this->_post("embd/db/detail",
            array(
                "database" => "private",
                "collection_id" => $collection_id,
                "source" => $source_name,
                "text_content" => ($source_name != null) ? true: false
            )
        );
    }

    public function DBGetCurrentCollectionDetail(/*string*/ $source_name=null) {  // -> array|null
        $collection_name = $this->GetCurrentCollectionName();
        $collection_id = $this->DBGetCollectionIdfromName($collection_name);
        $collection_detail = $this->DBGetCollectionDetail($collection_id, $source_name);
        if ($collection_detail->validation_json("data", "list")) {
            return $collection_detail->get("data");
        }
        return null;
    }

    public function DBGetCurrentCollectionSourceDetail(/* string */ $source_name) {  // -> array|null
        $liste_collection = $this->DBGetCurrentCollectionDetail($source_name);
        if ($liste_collection) {
            foreach ($liste_collection as $entree) {
                if ($entree["source"] === $source_name) {
                    return $entree;
                }
            }
        }
        return null;
    }

    public function DBCreateCollection(/*string*/ $collection_name, /*string*/ $source) { // -> Holo6APIResponse
        // $collection_description = sprintf(__("From \"%s\"", "holo6"), $source);
        $collection_description = "pk:" . $this->settings->getServerName() . "/private/" . $collection_name;

        $password = $this->GetSearchDBPassword();
        if (strlen($password) > 0) {
            return $this->_post("embd/db/init",
                array(
                    "database" => "private",
                    "password" => $password,
                    "collection_name" => $collection_name,
                    "source" => $source,
                    "description" => $collection_description
                )
            );
        }
        return new Holo6APIResponse(513);
    }

    public function DBAddCollectionData(/*string*/ $title, /*string*/ $source, /*string*/ $summary, /*string*/ $full_text) { // -> Holo6APIResponse
        $collection_name = $this->GetCurrentCollectionName();
        $password = $this->GetSearchDBPassword();
        if (strlen($password) > 0) {
            $collection_id = $this->DBGetCollectionIdfromName($collection_name);
            if (strlen($collection_id) === 0) {
                $create_result = $this->DBCreateCollection($collection_name, $source);
                $collection_id = $this->DBGetCollectionIdfromName($collection_name);
            }
            if (strlen($collection_id) > 0) {
                return $this->_post("embd/db/add",
                    array(
                        "database" => "private",
                        "password" => $password,
                        "collection_id" => $collection_id,
                        "passage" => $summary,
                        "extended" => $full_text,
                        "source" => $source,
                        "page" => -1,
                        "title" => $title
                    )
                );
            }
        }
        return new Holo6APIResponse(513);
    }

    public function _post($url, $post_data) { // -> Holo6APIResponse
        $ch = curl_init($this->settings->getAPIServer() . $url);
//         echo("KEY(" . $this->full_api_key . ")");
        curl_setopt_array($ch, array(CURLOPT_RETURNTRANSFER => true,
                                     CURLOPT_HEADER => false,
                                     CURLOPT_POST => true,
                                     CURLOPT_HTTPHEADER => array("User-Agent: Holo6PHP",
                                        "Accept: application/json",
                                        "Content-Type: application/json",
                                        "Authorization: Bearer " . $this->full_api_key,
                                     ),
                                     CURLOPT_POSTFIELDS => json_encode($post_data),
                                     CURLOPT_FOLLOWLOCATION => true,
                                     CURLOPT_SSL_VERIFYPEER => (!$this->ignore_ssl_key_verify),
                                     CURLOPT_MAXREDIRS => 10,
                                     CURLOPT_TIMEOUT => 30));
        $response = curl_exec($ch);
        $error = curl_error($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if (strlen($error) > 0) {
            return new Holo6APIResponse($httpCode, $error);
        }
        else {
            $json_data = json_decode($response, true);
            return new Holo6APIResponse($httpCode, $json_data);
        }
    }

    public function _get($url) { // -> Holo6APIResponse
        $ch = curl_init($this->settings->getAPIServer() . $url);
        curl_setopt_array($ch, array(CURLOPT_RETURNTRANSFER => true,
                                     CURLOPT_HEADER => false,
                                     CURLOPT_POST => false,
                                     CURLOPT_HTTPHEADER => array("User-Agent: Holo6PHP",
                                        "Accept: application/json",
                                        "Content-Type: application/json",
                                        "Authorization: Bearer " . $this->full_api_key,
                                     ),
                                     CURLOPT_FOLLOWLOCATION => true,
                                     CURLOPT_SSL_VERIFYPEER => (!$this->ignore_ssl_key_verify),
                                     CURLOPT_MAXREDIRS => 10,
                                     CURLOPT_TIMEOUT => 30));
        $response = curl_exec($ch);
        $error = curl_error($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if (strlen($error) > 0) {
            return new Holo6APIResponse($httpCode, $error);
        }
        else {
            $json_data = json_decode($response, true);
            return new Holo6APIResponse($httpCode, $json_data);
        }
    }
};

?>